@@ -28,6 +28,7 @@ from openbb_terminal.portfolio.portfolio_optimization.statics import (
     RISK_CHOICES,
     TIME_FACTOR,
 )
+from openbb_terminal.portfolio.portfolio_optimization.optimizer_helper import get_kwarg
 from openbb_terminal.portfolio.portfolio_optimization.po_engine import PoEngine
 from openbb_terminal.rich_config import console
 
@@ -121,11 +122,11 @@ def display_ef(portfolio_engine: PoEngine = None, **kwargs):
     >>> openbb.portfolio.po.ef_chart(portfolio_engine=p)
     """
 
-    n_portfolios = kwargs.get("n_portfolios", 100)
-    freq = kwargs.get("freq", "D")
-    risk_measure = kwargs.get("risk_measure", "MV")
-    risk_free_rate = kwargs.get("risk_free_rate", 0.0)
-    alpha = kwargs.get("alpha", 0.05)
+    n_portfolios = get_kwarg("n_portfolios", kwargs)
+    freq = get_kwarg("freq", kwargs)
+    risk_measure = get_kwarg("risk_measure", kwargs)
+    risk_free_rate = get_kwarg("risk_free_rate", kwargs)
+    alpha = get_kwarg("alpha", kwargs)
 
     # Pop chart args
     tangency = kwargs.pop("tangency", False)
@@ -403,7 +404,10 @@ def display_heat(**kwargs):
     external_axes = kwargs.get("external_axes", None)
 
     if len(weights) == 1:
-        console.print(f"Heatmap needs at least two values for '{category}'.")
+        single_key = list(weights.keys())[0].upper()
+        console.print(
+            f"[yellow]Heatmap needs at least two values for '{category}', only found '{single_key}'.[/yellow]"
+        )
         return
 
     if external_axes is None:
@@ -482,16 +486,17 @@ def display_rc(**kwargs):
     weights = kwargs.get("weights", None)
     data = kwargs.get("data", None)
     colors = kwargs.get("colors", None)
-    risk_measure = kwargs.get("risk_measure", "MV")
-    risk_free_rate = kwargs.get("risk_free_rate", 0.0)
     title = kwargs.get("title", "")
-    alpha = kwargs.get("alpha", 0.05)
-    a_sim = kwargs.get("a_sim", 100.0)
-    beta = kwargs.get("beta", 0.0)
-    b_sim = kwargs.get("b_sim", 0.0)
-    freq = kwargs.get("freq", "D")
     external_axes = kwargs.get("external_axes", None)
 
+    risk_measure = get_kwarg("risk_measure", kwargs)
+    risk_free_rate = get_kwarg("risk_free_rate", kwargs)
+    alpha = get_kwarg("alpha", kwargs)
+    a_sim = get_kwarg("a_sim", kwargs)
+    beta = get_kwarg("beta", kwargs)
+    b_sim = get_kwarg("b_sim", kwargs)
+    freq = get_kwarg("freq", kwargs)
+
     if external_axes is None:
         _, ax = plt.subplots(figsize=plot_autoscale(), dpi=PLOT_DPI)
     else:
@@ -533,9 +538,10 @@ def display_hist(**kwargs):
     data = kwargs.get("data", None)
     colors = kwargs.get("colors", None)
     title = kwargs.get("title", "")
-    alpha = kwargs.get("alpha", 0.05)
     external_axes = kwargs.get("external_axes", None)
 
+    alpha = kwargs.get("alpha", 0.05)
+
     if external_axes is None:
         _, ax = plt.subplots(figsize=plot_autoscale(), dpi=PLOT_DPI)
     else:
@@ -571,9 +577,10 @@ def display_dd(**kwargs):
     data = kwargs.get("data", None)
     colors = kwargs.get("colors", None)
     title = kwargs.get("title", "")
-    alpha = kwargs.get("alpha", 0.05)
     external_axes = kwargs.get("external_axes", None)
 
+    alpha = get_kwarg("alpha", kwargs)
+
     if external_axes is None:
         _, ax = plt.subplots(figsize=plot_autoscale(), dpi=PLOT_DPI)
     else:
